@@ -16,14 +16,15 @@ query = "SELECT variant_id, chrom, start, end, \
 
 families = subjects.get_families(database)
 
-gq.run(query)
-smp2idx = gq.sample_to_idx
-idx = smp2idx['NA12878']
+gq.run(query, gt_filter="gt_types.(hair_color='purple').(==HET) and gts.M128215 == 'T/T'")
+#smp2idx = gq.sample_to_idx
+#idx = smp2idx['NA12878']
 
 for family in families:
     print family.father_name, family.mother_name, [str(child.name) for child in family.children]
 
 for row in gq:
-    if row['gt_types'][idx] == const.HET:
-        print row, row['gts'][idx]
+    print row
+    #if row['gt_types'][idx] == const.HET:
+    #    print row, row['gts'][idx]
 
