@@ -323,7 +323,13 @@ class GeminiQuery(object):
         self.for_browser = False
         self.include_gt_cols = include_gt_cols
 
+        # try to connect to the provided database
         self._connect_to_database()
+
+        # extract the column names from the sample table.
+        # needed for gt-filter wildcard support.
+        self._collect_sample_table_columns()
+
         # map sample names to indices. e.g. self.sample_to_idx[NA20814] -> 323
         self.sample_to_idx = util.map_samples_to_indices(self.c)
         # and vice versa. e.g., self.idx_to_sample[323] ->  NA20814
@@ -349,6 +355,9 @@ class GeminiQuery(object):
         """
         self.query = self.formatter.format_query(query)
         self.gt_filter = gt_filter
+        if self._is_gt_filter_safe() is False:
+            sys.exit("ERROR: invalid --gt-filter command.")
+
         self.show_variant_samples = show_variant_samples
         self.variant_samples_delim = variant_samples_delim
         self.needs_genotypes = needs_genotypes
@@ -362,6 +371,7 @@ class GeminiQuery(object):
         self.query = self.query.replace(',', ', ')
         self.query_pieces = self.query.split()
         if not any(s.startswith("gt") for s in self.query_pieces) and \
+           not any(s.startswith("(gt") for s in self.query_pieces) and \
            not any(".gt" in s for s in self.query_pieces):
             if self.gt_filter is None:
                 self.query_type = "no-genotypes"
@@ -572,6 +582,44 @@ class GeminiQuery(object):
             self.conn.row_factory = sqlite3.Row
             self.c = self.conn.cursor()
 
+    def _collect_sample_table_columns(self):            
+        """
+        extract the column names in the samples table into a list
+        """
+        self.c.execute('select * from samples limit 1')
+        self.sample_column_names = [tup[0] for tup in self.c.description]
+
+    def _is_gt_filter_safe(self):
+        """
+        Test to see if the gt_filter string is potentially malicious.
+        
+        A future improvement would be to use pyparsing to
+        traverse and directly validate the string.
+        """
+        if self.gt_filter is None:
+            return True
+
+        # avoid builtins
+        # http://nedbatchelder.com/blog/201206/eval_really_is_dangerous.html
+        if "__" in self.gt_filter:
+            return False
+
+        # avoid malicious commands
+        evil = [" rm ", "os.system"]
+        if any(s in self.gt_filter for s in evil):
+            return False
+
+        # make sure a "gt" col is in the string
+        valid_cols = ["gts.", "gt_types.", "gt_phases.", "gt_quals.",
+                      "gt_depths.", "gt_ref_depths.", "gt_alt_depths.",
+                      "(gts).", "(gt_types).", "(gt_phases).", "(gt_quals).",
+                      "(gt_depths).", "(gt_ref_depths).", "(gt_alt_depths)."]
+        if any(s in self.gt_filter for s in valid_cols):
+            return True
+
+        # assume the worst
+        return False
+
     def _execute_query(self):
         try:
             self.c.execute(self.query)
@@ -632,8 +680,8 @@ class GeminiQuery(object):
         """
         if raw_col == "*":
             return raw_col.lower()
+        # e.g., "gts.NA12878"
         elif '.' in raw_col:
-            # e.g., "gts.NA12878"
             (column, sample) = raw_col.split('.', 1)
             corrected = column.lower() + "[" + str(self.sample_to_idx[sample]).lower() + "]"
         else:
@@ -641,27 +689,91 @@ class GeminiQuery(object):
             corrected = raw_col
         return corrected
 
+    def _get_matching_sample_ids(self, wildcard):
+        """
+        Helper function to convert a sample wildcard
+        to a list of tuples reflecting the sample indices 
+        and sample names so that the wildcard
+        query can be applied to the gt_* columns.
+        """
+        query = 'SELECT sample_id, name FROM samples '
+        if wildcard != "*":
+           query += ' WHERE ' + wildcard
+    
+        sample_info = [] # list of sample_id/name tuples
+        self.c.execute(query)
+        for row in self.c:
+            # sample_ids are 1-based but gt_* indices are 0-based
+            sample_info.append((int(row['sample_id']) - 1, str(row['name'])))
+        return sample_info
+
     def _correct_genotype_filter(self):
         """
-        This converts a "raw" genotype filter supplied by the user
-        to a filter than can be eval()'ed.  Specifically, we must
-        convery a _named_ genotype index to a _numerical_
-        genotype index so that the appropriate value can be
-        extracted for the sample from the genotype numpy arrays.
+        This converts a raw genotype filter that contains 
+        'wildcard' statements into a filter that can be eval()'ed.
+        Specifically, we must convert a _named_ genotype index 
+        to a _numerical_ genotype index so that the appropriate 
+        value can be extracted for the sample from the genotype 
+        numpy arrays.
 
-        For example, converts:
+        For example, without WILDCARDS, this converts:
         --gt-filter "(gt_types.1478PC0011 == 1)"
-        to
+        
+        to:
         (gt_types[11] == 1)
+
+        With WILDCARDS, this converts things like:
+            "(gt_types).(phenotype==1).(==HET)"
+
+        to:
+            "gt_types[2] == HET and gt_types[5] == HET"
         """
         corrected_gt_filter = []
-        tokens = re.split(r'[\s+]+', str(self.gt_filter))
-        for token in tokens:
-            if token.find("gt") >= 0 or token.find("GT") >= 0:
-                corrected = self._correct_genotype_col(token)
-                corrected_gt_filter.append(corrected)
+
+        # first try to identify wildcard rules.
+        wildcard_tokens = re.split(r'(\(.+?\)\.\(.+?\)\.\(.+?\))', str(self.gt_filter))
+        for token in wildcard_tokens:
+            # NOT a WILDCARD
+            # We must then split on whitespace and
+            # correct the gt_* columns:
+            # e.g., "gts.NA12878" or "and gt_types.M10500 == HET"
+            if (token.find("gt") >= 0 or token.find("GT") >= 0) \
+                and not '.(' in token and not ')self.' in token:
+                tokens = re.split(r'[\s+]+', str(token))
+                for t in tokens:
+                    if len(t) == 0:
+                        continue
+                    if (t.find("gt") >= 0 or t.find("GT") >= 0):
+                        corrected = self._correct_genotype_col(t)
+                        corrected_gt_filter.append(corrected)
+                    else:
+                        corrected_gt_filter.append(t)
+            # IS a WILDCARD
+            # e.g., "gt_types.(affected==1).(==HET)"
+            elif (token.find("gt") >= 0 or token.find("GT") >= 0) \
+                and '.(' in token and ').' in token:
+                # break the wildcard into its pieces. That is:
+                # (COLUMN).(WILDCARD).(WILDCARD_RULE)
+                (column, wildcard, wildcard_rule) = token.split('.')
+
+                # remove the syntactic parentheses
+                column = column.strip('(').strip(')')
+                wildcard = wildcard.strip('(').strip(')')
+                wildcard_rule = wildcard_rule.strip('(').strip(')')
+                
+                # convert "gt_types.(affected==1).(==HET)"
+                # to, e.g.,: gt_types[3] == HET and gt_types[9] == HET
+                sample_info = self._get_matching_sample_ids(wildcard)
+                for (idx, sample) in enumerate(sample_info):
+                    if idx < len(sample_info) - 1:
+                        rule = column + '[' + str(sample[0]) + '] ' + wildcard_rule + ' and '
+                    else:
+                        rule = column + '[' + str(sample[0]) + '] ' + wildcard_rule
+                    corrected_gt_filter.append(rule)
             else:
-                corrected_gt_filter.append(token)
+                if len(token) > 0:
+                    corrected_gt_filter.append(token)
+
         return " ".join(corrected_gt_filter)
 
 
@@ -690,7 +802,9 @@ class GeminiQuery(object):
             if not token.startswith("gt") and \
                not token.startswith("GT") and \
                not ".gt" in token and \
-               not ".GT" in token:
+               not ".GT" in token and \
+               not token.startswith("(gt") and \
+               not token.startswith("(GT"):
                 select_clause_list.append(token)
 
         # reconstruct the query with the GT* columns added
@@ -757,19 +871,57 @@ class GeminiQuery(object):
         (select_tokens, rest_of_query) = get_select_cols_and_rest(self.query)
 
         for token in select_tokens:
-            if not token.startswith("GT") and not token.startswith("gt"):
-                self.select_columns.append(token)
-                self.all_columns_new.append(token)
-                self.all_columns_orig.append(token)
-            else:
+            
+            # it is a WILDCARD
+            if (token.find("gt") >= 0 or token.find("GT") >= 0) \
+                and '.(' in token and ').' in token:
+                # break the wildcard into its pieces. That is:
+                # (COLUMN).(WILDCARD)
+                (column, wildcard) = token.split('.')
+
+                # remove the syntactic parentheses
+                wildcard = wildcard.strip('(').strip(')')
+                column = column.strip('(').strip(')')
+
+                # convert "gt_types.(affected==1)"
+                # to: gt_types[3] == HET and gt_types[9] == HET
+                sample_info = self._get_matching_sample_ids(wildcard)
+                
+                # maintain a list of the sample indices that should
+                # be displayed as a result of the SELECT'ed wildcard
+                wildcard_indices = []
+                for (idx, sample) in enumerate(sample_info):
+                    wildcard_display_col = column + '.' + str(sample[1])
+                    wildcard_mask_col = column + '[' + str(sample[0]) + ']'
+                    wildcard_indices.append(sample[0])
+
+                    new_col = wildcard_mask_col
+                    self.all_columns_new.append(new_col)
+                    self.all_columns_orig.append(wildcard_display_col)
+                    self.gt_name_to_idx_map[wildcard_display_col] = wildcard_mask_col
+                    self.gt_idx_to_name_map[wildcard_mask_col] = wildcard_display_col
+
+            # it is a basic genotype column
+            elif (token.find("gt") >= 0 or token.find("GT") >= 0) \
+                and '.(' not in token and not ').' in token:
                 new_col = self._correct_genotype_col(token)
+
                 self.all_columns_new.append(new_col)
                 self.all_columns_orig.append(token)
                 self.gt_name_to_idx_map[token] = new_col
                 self.gt_idx_to_name_map[new_col] = token
-    
+
+            # it is neither
+            else:
+                self.select_columns.append(token)
+                self.all_columns_new.append(token)
+                self.all_columns_orig.append(token)
+
     def _info_dict_to_string(self, info):
-        "Flatten the VCF info-field OrderedDict into a string, including all arrays for allelic-level info"
+        """
+        Flatten the VCF info-field OrderedDict into a string, 
+        including all arrays for allelic-level info.
+        """
         if info is not None:
             return ';'.join(['%s=%s' % (key, value) if not isinstance(value, list) \
                              else '%s=%s' % (key, ','.join([str(v) for v in value])) \
@@ -785,6 +937,7 @@ class GeminiQuery(object):
         tokens = self._tokenize_query()
         requested_genotype = "variants" in tokens and \
                             (any([x.startswith("gt") for x in tokens]) or \
+                             any([x.startswith("(gt") for x in tokens]) or \
                              any(".gt" in x for x in tokens))   
         return requested_genotype or \
                self.include_gt_cols or \
