@@ -98,10 +98,15 @@ def main():
     parser_load.add_argument('-p', dest='ped_file',
                              help='Sample information file in PED+ format.',
                              default=None)
-    parser_load.add_argument('--load-gerp-bp',
-                             dest='load_gerp_bp',
+    parser_load.add_argument('--skip-gerp-bp',
+                             dest='skip_gerp_bp',
                              action='store_true',
-                             help='Load GERP scores at base pair resolution. Slow. Off by default.',
+                             help='Do not load GERP scores at base pair resolution. Loaded by default.',
+                             default=False)
+    parser_load.add_argument('--skip-cadd',
+                             dest='skip_cadd',
+                             action='store_true',
+                             help='Do not load CADD scores. Loaded by default',
                              default=False)
     parser_load.add_argument('--skip-gene-tables',
                              dest='skip_gene_tables',
@@ -196,11 +201,16 @@ def main():
                                   action='store_true',
                                   help='There are no genotypes in the file (e.g. some 1000G VCFs)',
                                   default=False)
-    parser_loadchunk.add_argument('--load-gerp-bp',
-                                  dest='load_gerp_bp',
+    parser_loadchunk.add_argument('--skip-gerp-bp',
+                                  dest='skip_gerp_bp',
                                   action='store_true',
-                                  help='Load GERP scores at base pair resolution. Slow. Off by default.',
+                                  help='Do not load GERP scores at base pair resolution. Loaded by default.',
                                   default=False)
+    parser_loadchunk.add_argument('--skip-cadd',
+                                 dest='skip_cadd',
+                                 action='store_true',
+                                 help='Do not load CADD scores. Loaded by default',
+                                 default=False)
     parser_loadchunk.add_argument('--skip-gene-tables',
                              dest='skip_gene_tables',
                              action='store_true',
@@ -458,6 +468,10 @@ def main():
             metavar='QUERY_STR',
             default=None,
             help='The query to be issued to the database to summarize')
+    parser_stats.add_argument('--gt-filter',
+            dest='gt_filter',
+            metavar='STRING',
+            help='Restrictions to apply to genotype values')
     parser_stats.set_defaults(func=gemini_stats.stats)
 
     #########################################
@@ -894,7 +908,7 @@ def main():
     parser_update.add_argument("--dataonly", help="Only update data, not the underlying libraries.",
                                action="store_true", default=False)
     parser_update.add_argument("--extra", help="Add additional non-standard genome annotations to include",
-                               action="append", default=[], choices=["gerp_bp"])
+                               action="append", default=[], choices=["gerp_bp","cadd_score"])
     parser_update.set_defaults(func=gemini_update.release)
 
 
